# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# DecompositionType category 'Initial'
#
return <<'END';
FB54		
FB58		
FB5C		
FB60		
FB64		
FB68		
FB6C		
FB70		
FB74		
FB78		
FB7C		
FB80		
FB90		
FB94		
FB98		
FB9C		
FBA2		
FBA8		
FBAC		
FBD5		
FBE6		
FBE8		
FBF8		
FBFB		
FBFE		
FC97	FCDE	
FD2D	FD33	
FD50		
FD52	FD57	
FD59		
FD5C	FD5D	
FD60	FD61	
FD63		
FD65		
FD68		
FD6B		
FD6D		
FD70		
FD72	FD73	
FD77		
FD7D		
FD83		
FD86		
FD88	FD8A	
FD8C	FD8F	
FD92	FD95	
FD98		
FD9D		
FDB4	FDB5	
FDB8		
FDBA		
FDC3	FDC5	
FE8B		
FE91		
FE97		
FE9B		
FE9F		
FEA3		
FEA7		
FEB3		
FEB7		
FEBB		
FEBF		
FEC3		
FEC7		
FECB		
FECF		
FED3		
FED7		
FEDB		
FEDF		
FEE3		
FEE7		
FEEB		
FEF3		
END
