# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# Binary property 'IDS_Trinary_Operator'
#
return <<'END';
2FF2	2FF3	IDS_Trinary_Operator
END
