# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# This file supports:
# 	\p{Hangul} (and fuzzy permutations)
# 
# Meaning: Script 'Hangul'
#
return <<'END';
1100	1159	Hangul
115F	11A2	Hangul
11A8	11F9	Hangul
3131	318E	Hangul
3200	321E	Hangul
3260	327D	Hangul
AC00	D7A3	Hangul
FFA0	FFBE	Hangul
FFC2	FFC7	Hangul
FFCA	FFCF	Hangul
FFD2	FFD7	Hangul
FFDA	FFDC	Hangul
END
