# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# Binary property 'Bidi_Control'
#
return <<'END';
200E	200F	Bidi_Control
202A	202E	Bidi_Control
END
