# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# Linebreak category 'Quotation'
#
return <<'END';
0022		
0027		
00AB		
00BB		
2018	2019	
201B	201D	
201F		
2039	203A	
23B6		
275B	275E	
2E00	2E0D	
2E1C	2E1D	
END
