# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# This file supports:
# 	\p{OldPersian} (and fuzzy permutations)
# 
# Meaning: Script 'Old_Persian'
#
return <<'END';
103A0	103C3	Old_Persian
103C8	103D5	Old_Persian
END
