# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# JoiningType category 'Non_Joining'
#
return <<'END';
0600	0603	
060B		
0621		
0674		
06DD		
200C		
END
