# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# JoiningType category 'Right_Joining'
#
return <<'END';
0622	0625	
0627		
0629		
062F	0632	
0648		
0671	0673	
0675	0677	
0688	0699	
06C0		
06C3	06CB	
06CD		
06CF		
06D2	06D3	
06D5		
06EE	06EF	
0710		
0715	0719	
071E		
0728		
072A		
072C		
072F		
074D		
0759	075B	
076B	076C	
END
