# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# This file supports:
# 	\p{Cf}
# 	\p{Cf} (and fuzzy permutations)
# 
# Meaning: General Category 'Cf'
#
return <<'END';
00AD		
0600	0603	
06DD		
070F		
17B4	17B5	
200B	200F	
202A	202E	
2060	2063	
206A	206F	
FEFF		
FFF9	FFFB	
1D173	1D17A	
E0001		
E0020	E007F	
END
