# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# Linebreak category 'Infix_Numeric'
#
return <<'END';
002C		
002E		
003A	003B	
037E		
0589		
060D		
2044		
FE10		
FE13	FE14	
END
