( cd usr/bin ; rm -rf perl )
( cd usr/bin ; ln -sf perl5.8.7 perl )
( cd usr/bin ; rm -rf pstruct )
( cd usr/bin ; ln -sf c2ph pstruct )
( cd usr/bin ; rm -rf psed )
( cd usr/bin ; ln -sf s2p psed )
( cd usr/man/man1 ; rm -rf psed.1.gz )
( cd usr/man/man1 ; ln -sf s2p.1.gz psed.1.gz )
( cd usr/man/man1 ; rm -rf pstruct.1.gz )
( cd usr/man/man1 ; ln -sf c2ph.1.gz pstruct.1.gz )
