# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# DecompositionType category 'Fraction'
#
return <<'END';
00BC	00BE	
2153	215F	
END
