# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# NumericType category 'Digit'
#
return <<'END';
00B2	00B3	
00B9		
1369	1371	
2070		
2074	2079	
2080	2089	
2460	2468	
2474	247C	
2488	2490	
24EA		
24F5	24FD	
24FF		
2776	277E	
2780	2788	
278A	2792	
10A40	10A43	
END
