# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# HangulSyllableType category 'Trailing_Jamo'
#
return <<'END';
11A8	11F9	
END
