# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# This file supports:
# 	\p{VariationSelector} (and fuzzy permutations)
# 
# Meaning: Extended property 'Variation_Selector'
#
return <<'END';
180B	180D	Variation_Selector
FE00	FE0F	Variation_Selector
E0100	E01EF	Variation_Selector
END
