# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# HangulSyllableType category 'LVT_Syllable'
#
return <<'END';
AC01	AC1B	
AC1D	AC37	
AC39	AC53	
AC55	AC6F	
AC71	AC8B	
AC8D	ACA7	
ACA9	ACC3	
ACC5	ACDF	
ACE1	ACFB	
ACFD	AD17	
AD19	AD33	
AD35	AD4F	
AD51	AD6B	
AD6D	AD87	
AD89	ADA3	
ADA5	ADBF	
ADC1	ADDB	
ADDD	ADF7	
ADF9	AE13	
AE15	AE2F	
AE31	AE4B	
AE4D	AE67	
AE69	AE83	
AE85	AE9F	
AEA1	AEBB	
AEBD	AED7	
AED9	AEF3	
AEF5	AF0F	
AF11	AF2B	
AF2D	AF47	
AF49	AF63	
AF65	AF7F	
AF81	AF9B	
AF9D	AFB7	
AFB9	AFD3	
AFD5	AFEF	
AFF1	B00B	
B00D	B027	
B029	B043	
B045	B05F	
B061	B07B	
B07D	B097	
B099	B0B3	
B0B5	B0CF	
B0D1	B0EB	
B0ED	B107	
B109	B123	
B125	B13F	
B141	B15B	
B15D	B177	
B179	B193	
B195	B1AF	
B1B1	B1CB	
B1CD	B1E7	
B1E9	B203	
B205	B21F	
B221	B23B	
B23D	B257	
B259	B273	
B275	B28F	
B291	B2AB	
B2AD	B2C7	
B2C9	B2E3	
B2E5	B2FF	
B301	B31B	
B31D	B337	
B339	B353	
B355	B36F	
B371	B38B	
B38D	B3A7	
B3A9	B3C3	
B3C5	B3DF	
B3E1	B3FB	
B3FD	B417	
B419	B433	
B435	B44F	
B451	B46B	
B46D	B487	
B489	B4A3	
B4A5	B4BF	
B4C1	B4DB	
B4DD	B4F7	
B4F9	B513	
B515	B52F	
B531	B54B	
B54D	B567	
B569	B583	
B585	B59F	
B5A1	B5BB	
B5BD	B5D7	
B5D9	B5F3	
B5F5	B60F	
B611	B62B	
B62D	B647	
B649	B663	
B665	B67F	
B681	B69B	
B69D	B6B7	
B6B9	B6D3	
B6D5	B6EF	
B6F1	B70B	
B70D	B727	
B729	B743	
B745	B75F	
B761	B77B	
B77D	B797	
B799	B7B3	
B7B5	B7CF	
B7D1	B7EB	
B7ED	B807	
B809	B823	
B825	B83F	
B841	B85B	
B85D	B877	
B879	B893	
B895	B8AF	
B8B1	B8CB	
B8CD	B8E7	
B8E9	B903	
B905	B91F	
B921	B93B	
B93D	B957	
B959	B973	
B975	B98F	
B991	B9AB	
B9AD	B9C7	
B9C9	B9E3	
B9E5	B9FF	
BA01	BA1B	
BA1D	BA37	
BA39	BA53	
BA55	BA6F	
BA71	BA8B	
BA8D	BAA7	
BAA9	BAC3	
BAC5	BADF	
BAE1	BAFB	
BAFD	BB17	
BB19	BB33	
BB35	BB4F	
BB51	BB6B	
BB6D	BB87	
BB89	BBA3	
BBA5	BBBF	
BBC1	BBDB	
BBDD	BBF7	
BBF9	BC13	
BC15	BC2F	
BC31	BC4B	
BC4D	BC67	
BC69	BC83	
BC85	BC9F	
BCA1	BCBB	
BCBD	BCD7	
BCD9	BCF3	
BCF5	BD0F	
BD11	BD2B	
BD2D	BD47	
BD49	BD63	
BD65	BD7F	
BD81	BD9B	
BD9D	BDB7	
BDB9	BDD3	
BDD5	BDEF	
BDF1	BE0B	
BE0D	BE27	
BE29	BE43	
BE45	BE5F	
BE61	BE7B	
BE7D	BE97	
BE99	BEB3	
BEB5	BECF	
BED1	BEEB	
BEED	BF07	
BF09	BF23	
BF25	BF3F	
BF41	BF5B	
BF5D	BF77	
BF79	BF93	
BF95	BFAF	
BFB1	BFCB	
BFCD	BFE7	
BFE9	C003	
C005	C01F	
C021	C03B	
C03D	C057	
C059	C073	
C075	C08F	
C091	C0AB	
C0AD	C0C7	
C0C9	C0E3	
C0E5	C0FF	
C101	C11B	
C11D	C137	
C139	C153	
C155	C16F	
C171	C18B	
C18D	C1A7	
C1A9	C1C3	
C1C5	C1DF	
C1E1	C1FB	
C1FD	C217	
C219	C233	
C235	C24F	
C251	C26B	
C26D	C287	
C289	C2A3	
C2A5	C2BF	
C2C1	C2DB	
C2DD	C2F7	
C2F9	C313	
C315	C32F	
C331	C34B	
C34D	C367	
C369	C383	
C385	C39F	
C3A1	C3BB	
C3BD	C3D7	
C3D9	C3F3	
C3F5	C40F	
C411	C42B	
C42D	C447	
C449	C463	
C465	C47F	
C481	C49B	
C49D	C4B7	
C4B9	C4D3	
C4D5	C4EF	
C4F1	C50B	
C50D	C527	
C529	C543	
C545	C55F	
C561	C57B	
C57D	C597	
C599	C5B3	
C5B5	C5CF	
C5D1	C5EB	
C5ED	C607	
C609	C623	
C625	C63F	
C641	C65B	
C65D	C677	
C679	C693	
C695	C6AF	
C6B1	C6CB	
C6CD	C6E7	
C6E9	C703	
C705	C71F	
C721	C73B	
C73D	C757	
C759	C773	
C775	C78F	
C791	C7AB	
C7AD	C7C7	
C7C9	C7E3	
C7E5	C7FF	
C801	C81B	
C81D	C837	
C839	C853	
C855	C86F	
C871	C88B	
C88D	C8A7	
C8A9	C8C3	
C8C5	C8DF	
C8E1	C8FB	
C8FD	C917	
C919	C933	
C935	C94F	
C951	C96B	
C96D	C987	
C989	C9A3	
C9A5	C9BF	
C9C1	C9DB	
C9DD	C9F7	
C9F9	CA13	
CA15	CA2F	
CA31	CA4B	
CA4D	CA67	
CA69	CA83	
CA85	CA9F	
CAA1	CABB	
CABD	CAD7	
CAD9	CAF3	
CAF5	CB0F	
CB11	CB2B	
CB2D	CB47	
CB49	CB63	
CB65	CB7F	
CB81	CB9B	
CB9D	CBB7	
CBB9	CBD3	
CBD5	CBEF	
CBF1	CC0B	
CC0D	CC27	
CC29	CC43	
CC45	CC5F	
CC61	CC7B	
CC7D	CC97	
CC99	CCB3	
CCB5	CCCF	
CCD1	CCEB	
CCED	CD07	
CD09	CD23	
CD25	CD3F	
CD41	CD5B	
CD5D	CD77	
CD79	CD93	
CD95	CDAF	
CDB1	CDCB	
CDCD	CDE7	
CDE9	CE03	
CE05	CE1F	
CE21	CE3B	
CE3D	CE57	
CE59	CE73	
CE75	CE8F	
CE91	CEAB	
CEAD	CEC7	
CEC9	CEE3	
CEE5	CEFF	
CF01	CF1B	
CF1D	CF37	
CF39	CF53	
CF55	CF6F	
CF71	CF8B	
CF8D	CFA7	
CFA9	CFC3	
CFC5	CFDF	
CFE1	CFFB	
CFFD	D017	
D019	D033	
D035	D04F	
D051	D06B	
D06D	D087	
D089	D0A3	
D0A5	D0BF	
D0C1	D0DB	
D0DD	D0F7	
D0F9	D113	
D115	D12F	
D131	D14B	
D14D	D167	
D169	D183	
D185	D19F	
D1A1	D1BB	
D1BD	D1D7	
D1D9	D1F3	
D1F5	D20F	
D211	D22B	
D22D	D247	
D249	D263	
D265	D27F	
D281	D29B	
D29D	D2B7	
D2B9	D2D3	
D2D5	D2EF	
D2F1	D30B	
D30D	D327	
D329	D343	
D345	D35F	
D361	D37B	
D37D	D397	
D399	D3B3	
D3B5	D3CF	
D3D1	D3EB	
D3ED	D407	
D409	D423	
D425	D43F	
D441	D45B	
D45D	D477	
D479	D493	
D495	D4AF	
D4B1	D4CB	
D4CD	D4E7	
D4E9	D503	
D505	D51F	
D521	D53B	
D53D	D557	
D559	D573	
D575	D58F	
D591	D5AB	
D5AD	D5C7	
D5C9	D5E3	
D5E5	D5FF	
D601	D61B	
D61D	D637	
D639	D653	
D655	D66F	
D671	D68B	
D68D	D6A7	
D6A9	D6C3	
D6C5	D6DF	
D6E1	D6FB	
D6FD	D717	
D719	D733	
D735	D74F	
D751	D76B	
D76D	D787	
D789	D7A3	
END
