# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# DecompositionType category 'Vertical'
#
return <<'END';
309F		
30FF		
FE10	FE19	
FE30	FE44	
FE47	FE48	
END
