# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# EastAsianWidth category 'Narrow'
#
return <<'END';
0020	007E	
00A2	00A3	
00A5	00A6	
00AC		
00AF		
27E6	27EB	
2985	2986	
END
