# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# Binary property 'Grapheme_Link'
#
return <<'END';
034F		Grapheme_Link
094D		Grapheme_Link
09CD		Grapheme_Link
0A4D		Grapheme_Link
0ACD		Grapheme_Link
0B4D		Grapheme_Link
0BCD		Grapheme_Link
0C4D		Grapheme_Link
0CCD		Grapheme_Link
0D4D		Grapheme_Link
0DCA		Grapheme_Link
0E3A		Grapheme_Link
1039		Grapheme_Link
17D2		Grapheme_Link
A806		Grapheme_Link
10A3F		Grapheme_Link
END
