# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# This file supports:
# 	\p{Georgian} (and fuzzy permutations)
# 
# Meaning: Script 'Georgian'
#
return <<'END';
10A0	10C5	Georgian
10D0	10FA	Georgian
10FC		Georgian
2D00	2D25	Georgian
END
