# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# DecompositionType category 'Sub'
#
return <<'END';
1D62	1D6A	
2080	208E	
2090	2094	
END
