# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# This file supports:
# 	\p{Deprecated} (and fuzzy permutations)
# 
# Meaning: Extended property 'Deprecated'
#
return <<'END';
0340	0341	Deprecated
17A3		Deprecated
17D3		Deprecated
206A	206F	Deprecated
END
