# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# BidiClass category 'European_Terminator'
#
return <<'END';
0023	0025	
00A2	00A5	
00B0	00B1	
066A		
09F2	09F3	
0AF1		
0BF9		
0E3F		
17DB		
2030	2034	
20A0	20B5	
212E		
2213		
FE5F		
FE69	FE6A	
FF03	FF05	
FFE0	FFE1	
FFE5	FFE6	
END
