# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# This file supports:
# 	\p{Co}
# 	\p{Co} (and fuzzy permutations)
# 
# Meaning: General Category 'Co'
#
return <<'END';
E000	F8FF	
F0000	FFFFD	
100000	10FFFD	
END
