# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# This file supports:
# 	\p{Pc}
# 	\p{Pc} (and fuzzy permutations)
# 
# Meaning: General Category 'Pc'
#
return <<'END';
005F		
203F	2040	
2054		
FE33	FE34	
FE4D	FE4F	
FF3F		
END
