# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# This file supports:
# 	\p{AsciiHexDigit} (and fuzzy permutations)
# 
# Meaning: Extended property 'ASCII_Hex_Digit'
#
return <<'END';
0030	0039	ASCII_Hex_Digit
0041	0046	ASCII_Hex_Digit
0061	0066	ASCII_Hex_Digit
END
