# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# This file supports:
# 	\p{Tagbanwa} (and fuzzy permutations)
# 
# Meaning: Script 'Tagbanwa'
#
return <<'END';
1760	176C	Tagbanwa
176E	1770	Tagbanwa
1772	1773	Tagbanwa
END
