# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# This file supports:
# 	\p{_CanonDCIJ}
# 
# Meaning: (for internal casefolding use)
#
return <<'END';
0069	006A	
012F		
1E2D		
1ECB		
END
