# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# Binary property 'Hex_Digit'
#
return <<'END';
0030	0039	Hex_Digit
0041	0046	Hex_Digit
0061	0066	Hex_Digit
FF10	FF19	Hex_Digit
FF21	FF26	Hex_Digit
FF41	FF46	Hex_Digit
END
