# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# Linebreak category 'Break_Before'
#
return <<'END';
00B4		
02C8		
02CC		
0F01	0F04	
0F06	0F07	
0F09	0F0A	
0FD0	0FD1	
1806		
END
