# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# This file supports:
# 	\p{Any}
# 	\p{Any}
# 
# Meaning: [\x{0000}-\x{10FFFF}]
#
return <<'END';
0000	10FFFF	
END
