# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# Linebreak category 'Next_Line'
#
return <<'END';
0085		
END
