# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!


%utf8::PropertyAlias = (
'sc',
'Script',
'xonfkd',
'ExpandsOnNFKD',
'patsyn',
'PatternSyntax',
'nfkcqc',
'NFKCQuickCheck',
'oalpha',
'OtherAlphabetic',
'gcb',
'GraphemeClusterBreak',
'nfcqc',
'NFCQuickCheck',
'ids',
'IDStart',
'lb',
'LineBreak',
'stc',
'SimpleTitlecaseMapping',
'xonfkc',
'ExpandsOnNFKC',
'patws',
'PatternWhiteSpace',
'tc',
'TitlecaseMapping',
'lower',
'Lowercase',
'idst',
'IDSTrinaryOperator',
'radical',
'Radical',
'fcnfkc',
'FCNFKCClosure',
'dm',
'DecompositionMapping',
'slc',
'SimpleLowercaseMapping',
'wspace',
'WhiteSpace',
'di',
'DefaultIgnorableCodePoint',
'nt',
'NumericType',
'ea',
'EastAsianWidth',
'ahex',
'ASCIIHexDigit',
'alpha',
'Alphabetic',
'uc',
'UppercaseMapping',
'dia',
'Diacritic',
'gc',
'GeneralCategory',
'xids',
'XIDStart',
'oupper',
'OtherUppercase',
'wb',
'WordBreak',
'math',
'Math',
'sb',
'SentenceBreak',
'qmark',
'QuotationMark',
'nfdqc',
'NFDQuickCheck',
'ideo',
'Ideographic',
'blk',
'Block',
'odi',
'OtherDefaultIgnorableCodePoint',
'hst',
'HangulSyllableType',
'bidim',
'BidiMirrored',
'olower',
'OtherLowercase',
'na',
'Name',
'hyphen',
'Hyphen',
'xidc',
'XIDContinue',
'oidc',
'OtherIDContinue',
'bidic',
'BidiControl',
'na1',
'Unicode1Name',
'compex',
'FullCompositionExclusion',
'ext',
'Extender',
'cf',
'CaseFolding',
'grlink',
'GraphemeLink',
'xonfc',
'ExpandsOnNFC',
'sd',
'SoftDotted',
'ccc',
'CanonicalCombiningClass',
'dash',
'Dash',
'hex',
'HexDigit',
'grbase',
'GraphemeBase',
'dt',
'DecompositionType',
'xonfd',
'ExpandsOnNFD',
'scc',
'SpecialCaseCondition',
'idsb',
'IDSBinaryOperator',
'age',
'Age',
'loe',
'LogicalOrderException',
'term',
'TerminalPunctuation',
'ce',
'CompositionExclusion',
'isc',
'ISOComment',
'dep',
'Deprecated',
'sfc',
'SimpleCaseFolding',
'bc',
'BidiClass',
'nchar',
'NoncharacterCodePoint',
'jt',
'JoiningType',
'upper',
'Uppercase',
'uideo',
'UnifiedIdeograph',
'sterm',
'STerm',
'nfkdqc',
'NFKDQuickCheck',
'oids',
'OtherIDStart',
'joinc',
'JoinControl',
'nv',
'NumericValue',
'suc',
'SimpleUppercaseMapping',
'urs',
'UnicodeRadicalStroke',
'bmg',
'BidiMirroringGlyph',
'grext',
'GraphemeExtend',
'idc',
'IDContinue',
'vs',
'VariationSelector',
'omath',
'OtherMath',
'lc',
'LowercaseMapping',
'ogrext',
'OtherGraphemeExtend',
'jg',
'JoiningGroup',
);

%utf8::PA_reverse = (
'linebreak',
'lb',
'bidiclass',
'bc',
'terminalpunctuation',
'Term',
'expandsonnfkc',
'XONFKC',
'extender',
'Ext',
'simplecasefolding',
'sfc',
'patternsyntax',
'PatSyn',
'sentencebreak',
'SB',
'numericvalue',
'nv',
'patternwhitespace',
'PatWS',
'softdotted',
'SD',
'logicalorderexception',
'LOE',
'idstart',
'IDS',
'generalcategory',
'gc',
'decompositiontype',
'dt',
'name',
'na',
'numerictype',
'nt',
'otherlowercase',
'OLower',
'joininggroup',
'jg',
'expandsonnfkd',
'XONFKD',
'deprecated',
'Dep',
'radical',
'Radical',
'idstrinaryoperator',
'IDST',
'xidstart',
'XIDS',
'lowercase',
'Lower',
'unifiedideograph',
'UIdeo',
'othergraphemeextend',
'OGrExt',
'eastasianwidth',
'ea',
'math',
'Math',
'graphemelink',
'GrLink',
'noncharactercodepoint',
'NChar',
'graphemebase',
'GrBase',
'bidimirrored',
'BidiM',
'casefolding',
'cf',
'simpleuppercasemapping',
'suc',
'fullcompositionexclusion',
'CompEx',
'compositionexclusion',
'CE',
'uppercasemapping',
'uc',
'decompositionmapping',
'dm',
'whitespace',
'WSpace',
'hyphen',
'Hyphen',
'ideographic',
'Ideo',
'idcontinue',
'IDC',
'idsbinaryoperator',
'IDSB',
'hangulsyllabletype',
'hst',
'asciihexdigit',
'AHex',
'otheruppercase',
'OUpper',
'nfkdquickcheck',
'NFKDQC',
'simpletitlecasemapping',
'stc',
'nfcquickcheck',
'NFCQC',
'bidicontrol',
'BidiC',
'diacritic',
'Dia',
'joiningtype',
'jt',
'otheralphabetic',
'OAlpha',
'canonicalcombiningclass',
'ccc',
'alphabetic',
'Alpha',
'titlecasemapping',
'tc',
'unicoderadicalstroke',
'URS',
'hexdigit',
'Hex',
'unicode1name',
'na1',
'dash',
'Dash',
'fcnfkcclosure',
'FCNFKC',
'graphemeextend',
'GrExt',
'joincontrol',
'JoinC',
'xidcontinue',
'XIDC',
'quotationmark',
'QMark',
'expandsonnfd',
'XONFD',
'age',
'age',
'otheridcontinue',
'OIDC',
'uppercase',
'Upper',
'expandsonnfc',
'XONFC',
'defaultignorablecodepoint',
'DI',
'nfdquickcheck',
'NFDQC',
'isocomment',
'isc',
'otherdefaultignorablecodepoint',
'ODI',
'variationselector',
'VS',
'specialcasecondition',
'scc',
'script',
'sc',
'otheridstart',
'OIDS',
'sterm',
'STerm',
'graphemeclusterbreak',
'GCB',
'nfkcquickcheck',
'NFKCQC',
'bidimirroringglyph',
'bmg',
'othermath',
'OMath',
'block',
'blk',
'wordbreak',
'WB',
'lowercasemapping',
'lc',
'simplelowercasemapping',
'slc',
);

%utf8::PropValueAlias = (
'sc',
{
'tglg',
'Tagalog',
'runr',
'Runic',
'osma',
'Osmanya',
'hano',
'Hanunoo',
'cans',
'CanadianAboriginal',
'tagb',
'Tagbanwa',
'mlym',
'Malayalam',
'knda',
'Kannada',
'grek',
'Greek',
'ethi',
'Ethiopic',
'orya',
'Oriya',
'cher',
'Cherokee',
'mong',
'Mongolian',
'khmr',
'Khmer',
'ogam',
'Ogham',
'hrkt',
'KatakanaOrHiragana',
'armn',
'Armenian',
'ital',
'OldItalic',
'hani',
'Han',
'shaw',
'Shavian',
'taml',
'Tamil',
'tibt',
'Tibetan',
'guru',
'Gurmukhi',
'ugar',
'Ugaritic',
'qaai',
'Inherited',
'kana',
'Katakana',
'gujr',
'Gujarati',
'thaa',
'Thaana',
'cyrl',
'Cyrillic',
'copt',
'Coptic',
'sylo',
'SylotiNagri',
'thai',
'Thai',
'talu',
'NewTaiLue',
'laoo',
'Lao',
'sinh',
'Sinhala',
'beng',
'Bengali',
'hira',
'Hiragana',
'brai',
'Braille',
'telu',
'Telugu',
'limb',
'Limbu',
'geor',
'Georgian',
'mymr',
'Myanmar',
'glag',
'Glagolitic',
'hang',
'Hangul',
'syrc',
'Syriac',
'tfng',
'Tifinagh',
'dsrt',
'Deseret',
'buhd',
'Buhid',
'yiii',
'Yi',
'arab',
'Arabic',
'bopo',
'Bopomofo',
'khar',
'Kharoshthi',
'linb',
'LinearB',
'deva',
'Devanagari',
'xpeo',
'OldPersian',
'goth',
'Gothic',
'cprt',
'Cypriot',
'tale',
'TaiLe',
'zyyy',
'Common',
'latn',
'Latin',
'bugi',
'Buginese',
'hebr',
'Hebrew',
},
'dt',
{
'fra',
'Fraction',
'none',
'None',
'sml',
'Small',
'enc',
'Circle',
'font',
'Font',
'init',
'Initial',
'nb',
'Nobreak',
'iso',
'Isolated',
'sup',
'Super',
'fin',
'Final',
'wide',
'Wide',
'nar',
'Narrow',
'can',
'Canonical',
'med',
'Medial',
'sub',
'Sub',
'vert',
'Vertical',
'sqr',
'Square',
'com',
'Compat',
},
'nt',
{
'none',
'None',
'di',
'Digit',
'de',
'Decimal',
'nu',
'Numeric',
},
'ea',
{
'w',
'Wide',
'n',
'Neutral',
'h',
'Halfwidth',
'a',
'Ambiguous',
'f',
'Fullwidth',
'na',
'Narrow',
},
'NFKC_QC',
{
'y',
'Yes',
'n',
'No',
'm',
'Maybe',
},
'bc',
{
'r',
'RightToLeft',
'rlo',
'RightToLeftOverride',
'es',
'EuropeanSeparator',
'ws',
'WhiteSpace',
'rle',
'RightToLeftEmbedding',
'on',
'OtherNeutral',
'bn',
'BoundaryNeutral',
'et',
'EuropeanTerminator',
'pdf',
'PopDirectionalFormat',
'lro',
'LeftToRightOverride',
's',
'SegmentSeparator',
'al',
'ArabicLetter',
'en',
'EuropeanNumber',
'l',
'LeftToRight',
'b',
'ParagraphSeparator',
'lre',
'LeftToRightEmbedding',
'cs',
'CommonSeparator',
'nsm',
'NonspacingMark',
'an',
'ArabicNumber',
},
'gc',
{
'sc',
'CurrencySymbol',
'mc',
'SpacingMark',
'lm',
'ModifierLetter',
'cn',
'Unassigned',
'pf',
'FinalPunctuation',
'no',
'OtherNumber',
'cc',
'Control',
'lo',
'OtherLetter',
'po',
'OtherPunctuation',
'zs',
'SpaceSeparator',
'co',
'PrivateUse',
'so',
'OtherSymbol',
'll',
'LowercaseLetter',
'nd',
'DecimalNumber',
'cf',
'Format',
'me',
'EnclosingMark',
's',
'Symbol',
'zp',
'ParagraphSeparator',
'pd',
'DashPunctuation',
'c',
'Other',
'lt',
'TitlecaseLetter',
'cs',
'Surrogate',
'l&',
'CasedLetter',
'z',
'Separator',
'ps',
'OpenPunctuation',
'zl',
'LineSeparator',
'pc',
'ConnectorPunctuation',
'pi',
'InitialPunctuation',
'n',
'Number',
'm',
'Mark',
'nl',
'LetterNumber',
'sm',
'MathSymbol',
'l',
'Letter',
'mn',
'NonspacingMark',
'p',
'Punctuation',
'lc',
'CasedLetter',
'sk',
'ModifierSymbol',
'lu',
'UppercaseLetter',
'pe',
'ClosePunctuation',
},
'GCB',
{
'cn',
'Control',
'ex',
'Extend',
'v',
'V',
'lv',
'LV',
'xx',
'Other',
'l',
'L',
'lvt',
'LVT',
'cr',
'CR',
'lf',
'LF',
't',
'T',
},
'lb',
{
'sp',
'Space',
'ba',
'BreakAfter',
'gl',
'Glue',
'xx',
'Unknown',
'nu',
'Numeric',
'cb',
'ContingentBreak',
'sy',
'BreakSymbols',
'cr',
'CarriageReturn',
'in',
'Inseparable',
'bb',
'BreakBefore',
'sg',
'Surrogate',
'sa',
'ComplexContext',
'po',
'PostfixNumeric',
'jl',
'JL',
'id',
'Ideographic',
'al',
'Alphabetic',
'bk',
'MandatoryBreak',
'pr',
'PrefixNumeric',
'b2',
'BreakBoth',
'op',
'OpenPunctuation',
'cl',
'ClosePunctuation',
'is',
'InfixNumeric',
'qu',
'Quotation',
'hy',
'Hyphen',
'wj',
'WordJoiner',
'zw',
'ZWSpace',
'jt',
'JT',
'ex',
'Exclamation',
'cm',
'CombiningMark',
'h2',
'H2',
'nl',
'NextLine',
'ns',
'Nonstarter',
'h3',
'H3',
'ai',
'Ambiguous',
'lf',
'LineFeed',
'jv',
'JV',
},
'jt',
{
'l',
'LeftJoining',
'u',
'NonJoining',
'c',
'JoinCausing',
'r',
'RightJoining',
'd',
'DualJoining',
't',
'Transparent',
},
'NFKD_QC',
{
'y',
'Yes',
'n',
'No',
},
'NFC_QC',
{
'y',
'Yes',
'n',
'No',
'm',
'Maybe',
},
'hst',
{
'l',
'LeadingJamo',
'lvt',
'LVTSyllable',
'v',
'VowelJamo',
'lv',
'LVSyllable',
't',
'TrailingJamo',
'na',
'NotApplicable',
},
'NFD_QC',
{
'y',
'Yes',
'n',
'No',
},
'WB',
{
'ml',
'MidLetter',
'le',
'ALetter',
'ex',
'ExtendNumLet',
'xx',
'Other',
'nu',
'Numeric',
'fo',
'Format',
'mn',
'MidNum',
'ka',
'Katakana',
},
'SB',
{
'sp',
'Sp',
'cl',
'Close',
'le',
'OLetter',
'up',
'Upper',
'st',
'STerm',
'xx',
'Other',
'nu',
'Numeric',
'fo',
'Format',
'se',
'Sep',
'lo',
'Lower',
'at',
'ATerm',
},
'ccc',
{
'atb',
'AttachedBelow',
'db',
'DoubleBelow',
'a',
'Above',
'r',
'Right',
'da',
'DoubleAbove',
'is',
'IotaSubscript',
'nr',
'NotReordered',
'ov',
'Overlay',
'br',
'BelowRight',
'nk',
'Nukta',
'atbl',
'AttachedBelowLeft',
'al',
'AboveLeft',
'ar',
'AboveRight',
'atar',
'AttachedAboveRight',
'l',
'Left',
'b',
'Below',
'vr',
'Virama',
'kv',
'KanaVoicing',
'bl',
'BelowLeft',
},
);

%utf8::PVA_reverse = (
'sc',
{
'newtailue',
'Talu',
'canadianaboriginal',
'Cans',
'gujarati',
'Gujr',
'latin',
'Latn',
'hangul',
'Hang',
'deseret',
'Dsrt',
'hebrew',
'Hebr',
'inherited',
'Qaai',
'linearb',
'Linb',
'ugaritic',
'Ugar',
'taile',
'Tale',
'armenian',
'Armn',
'tifinagh',
'Tfng',
'myanmar',
'Mymr',
'gurmukhi',
'Guru',
'greek',
'Grek',
'coptic',
'Copt',
'cyrillic',
'Cyrl',
'thaana',
'Thaa',
'lao',
'Laoo',
'katakana',
'Kana',
'khmer',
'Khmr',
'tibetan',
'Tibt',
'hiragana',
'Hira',
'mongolian',
'Mong',
'thai',
'Thai',
'yi',
'Yiii',
'sylotinagri',
'Sylo',
'bopomofo',
'Bopo',
'malayalam',
'Mlym',
'telugu',
'Telu',
'limbu',
'Limb',
'oriya',
'Orya',
'buhid',
'Buhd',
'cypriot',
'Cprt',
'bengali',
'Beng',
'katakanaorhiragana',
'Hrkt',
'oldpersian',
'Xpeo',
'tagalog',
'Tglg',
'syriac',
'Syrc',
'cherokee',
'Cher',
'ogham',
'Ogam',
'hanunoo',
'Hano',
'braille',
'Brai',
'tamil',
'Taml',
'common',
'Zyyy',
'runic',
'Runr',
'georgian',
'Geor',
'ethiopic',
'Ethi',
'glagolitic',
'Glag',
'han',
'Hani',
'kharoshthi',
'Khar',
'kannada',
'Knda',
'tagbanwa',
'Tagb',
'arabic',
'Arab',
'sinhala',
'Sinh',
'gothic',
'Goth',
'osmanya',
'Osma',
'olditalic',
'Ital',
'devanagari',
'Deva',
'buginese',
'Bugi',
'shavian',
'Shaw',
},
'dt',
{
'small',
'sml',
'none',
'none',
'isolated',
'iso',
'narrow',
'nar',
'square',
'sqr',
'nobreak',
'nb',
'fraction',
'fra',
'font',
'font',
'medial',
'med',
'wide',
'wide',
'canonical',
'can',
'circle',
'enc',
'super',
'sup',
'vertical',
'vert',
'final',
'fin',
'compat',
'com',
'sub',
'sub',
'initial',
'init',
},
'nt',
{
'none',
'None',
'digit',
'Di',
'numeric',
'Nu',
'decimal',
'De',
},
'ea',
{
'halfwidth',
'H',
'fullwidth',
'F',
'ambiguous',
'A',
'narrow',
'Na',
'wide',
'W',
'neutral',
'N',
},
'NFKC_QC',
{
'yes',
'Y',
'maybe',
'M',
'no',
'N',
},
'bc',
{
'nonspacingmark',
'NSM',
'whitespace',
'WS',
'righttoleft',
'R',
'lefttoright',
'L',
'boundaryneutral',
'BN',
'segmentseparator',
'S',
'lefttorightembedding',
'LRE',
'europeanterminator',
'ET',
'righttoleftembedding',
'RLE',
'righttoleftoverride',
'RLO',
'lefttorightoverride',
'LRO',
'europeanseparator',
'ES',
'europeannumber',
'EN',
'commonseparator',
'CS',
'arabicletter',
'AL',
'paragraphseparator',
'B',
'otherneutral',
'ON',
'popdirectionalformat',
'PDF',
'arabicnumber',
'AN',
},
'gc',
{
'modifiersymbol',
'Sk',
'letternumber',
'Nl',
'connectorpunctuation',
'Pc',
'spacingmark',
'Mc',
'mark',
'M',
'unassigned',
'Cn',
'enclosingmark',
'Me',
'lineseparator',
'Zl',
'lowercaseletter',
'Ll',
'symbol',
'S',
'letter',
'L',
'othernumber',
'No',
'paragraphseparator',
'Zp',
'modifierletter',
'Lm',
'titlecaseletter',
'Lt',
'decimalnumber',
'Nd',
'other',
'C',
'mathsymbol',
'Sm',
'surrogate',
'Cs',
'otherletter',
'Lo',
'nonspacingmark',
'Mn',
'number',
'N',
'uppercaseletter',
'Lu',
'spaceseparator',
'Zs',
'privateuse',
'Co',
'openpunctuation',
'Ps',
'punctuation',
'P',
'control',
'Cc',
'casedletter',
'LC',
'closepunctuation',
'Pe',
'otherpunctuation',
'Po',
'finalpunctuation',
'Pf',
'format',
'Cf',
'initialpunctuation',
'Pi',
'separator',
'Z',
'othersymbol',
'So',
'dashpunctuation',
'Pd',
'currencysymbol',
'Sc',
},
'GCB',
{
'extend',
'EX',
'v',
'V',
'lv',
'LV',
'l',
'L',
'lvt',
'LVT',
'cr',
'CR',
'other',
'XX',
'lf',
'LF',
'control',
'CN',
't',
'T',
},
'lb',
{
'carriagereturn',
'CR',
'ideographic',
'ID',
'hyphen',
'HY',
'ambiguous',
'AI',
'contingentbreak',
'CB',
'complexcontext',
'SA',
'prefixnumeric',
'PR',
'jl',
'JL',
'inseparable',
'IN',
'breaksymbols',
'SY',
'breakafter',
'BA',
'breakbefore',
'BB',
'postfixnumeric',
'PO',
'glue',
'GL',
'wordjoiner',
'WJ',
'breakboth',
'B2',
'quotation',
'QU',
'combiningmark',
'CM',
'nonstarter',
'NS',
'linefeed',
'LF',
'alphabetic',
'AL',
'surrogate',
'SG',
'mandatorybreak',
'BK',
'unknown',
'XX',
'exclamation',
'EX',
'openpunctuation',
'OP',
'jt',
'JT',
'closepunctuation',
'CL',
'space',
'SP',
'zwspace',
'ZW',
'h2',
'H2',
'infixnumeric',
'IS',
'nextline',
'NL',
'numeric',
'NU',
'h3',
'H3',
'jv',
'JV',
},
'jt',
{
'leftjoining',
'L',
'transparent',
'T',
'nonjoining',
'U',
'rightjoining',
'R',
'dualjoining',
'D',
'joincausing',
'C',
},
'NFKD_QC',
{
'yes',
'Y',
'no',
'N',
},
'NFC_QC',
{
'yes',
'Y',
'maybe',
'M',
'no',
'N',
},
'hst',
{
'lvtsyllable',
'LVT',
'lvsyllable',
'LV',
'leadingjamo',
'L',
'notapplicable',
'NA',
'voweljamo',
'V',
'trailingjamo',
'T',
},
'NFD_QC',
{
'yes',
'Y',
'no',
'N',
},
'WB',
{
'midletter',
'ML',
'format',
'FO',
'katakana',
'KA',
'other',
'XX',
'midnum',
'MN',
'numeric',
'NU',
'extendnumlet',
'EX',
'aletter',
'LE',
},
'SB',
{
'sp',
'SP',
'upper',
'UP',
'sterm',
'ST',
'aterm',
'AT',
'close',
'CL',
'oletter',
'LE',
'sep',
'SE',
'format',
'FO',
'other',
'XX',
'lower',
'LO',
'numeric',
'NU',
},
'ccc',
{
'left',
'L',
'attachedbelowleft',
'ATBL',
'belowleft',
'BL',
'aboveright',
'AR',
'kanavoicing',
'KV',
'above',
'A',
'aboveleft',
'AL',
'nukta',
'NK',
'below',
'B',
'doublebelow',
'DB',
'virama',
'VR',
'belowright',
'BR',
'notreordered',
'NR',
'attachedbelow',
'ATB',
'right',
'R',
'iotasubscript',
'IS',
'doubleabove',
'DA',
'attachedaboveright',
'ATAR',
'overlay',
'OV',
},
);

%utf8::PVA_abbr_map = (
'jt',
{
'l',
'L',
'u',
'U',
'c',
'C',
'r',
'R',
'd',
'D',
't',
'T',
},
'dt',
{
'fra',
'fra',
'none',
'none',
'sml',
'sml',
'enc',
'enc',
'font',
'font',
'init',
'init',
'nb',
'nb',
'iso',
'iso',
'sup',
'sup',
'fin',
'fin',
'wide',
'wide',
'nar',
'nar',
'can',
'can',
'med',
'med',
'sub',
'sub',
'vert',
'vert',
'sqr',
'sqr',
'com',
'com',
},
'nt',
{
'none',
'None',
'di',
'Di',
'de',
'De',
'nu',
'Nu',
},
'NFKD_QC',
{
'y',
'Y',
'n',
'N',
},
'ea',
{
'w',
'W',
'n',
'N',
'h',
'H',
'a',
'A',
'f',
'F',
'na',
'Na',
},
'gc_sc',
{
'runr',
'Runr',
'osma',
'Osma',
'sc',
'Sc',
'mc',
'Mc',
'hano',
'Hano',
'cans',
'Cans',
'lm',
'Lm',
'cn',
'Cn',
'knda',
'Knda',
'orya',
'Orya',
'cher',
'Cher',
'khmr',
'Khmr',
'ogam',
'Ogam',
'lo',
'Lo',
'po',
'Po',
'co',
'Co',
'ital',
'Ital',
'll',
'Ll',
'tibt',
'Tibt',
'kana',
'Kana',
'zp',
'Zp',
'gujr',
'Gujr',
'thaa',
'Thaa',
'cs',
'Cs',
'copt',
'Copt',
'z',
'Z',
'ps',
'Ps',
'sylo',
'Sylo',
'talu',
'Talu',
'laoo',
'Laoo',
'sinh',
'Sinh',
'zl',
'Zl',
'pc',
'Pc',
'hira',
'Hira',
'limb',
'Limb',
'mymr',
'Mymr',
'yiii',
'Yiii',
'arab',
'Arab',
'deva',
'Deva',
'xpeo',
'Xpeo',
'cprt',
'Cprt',
'bugi',
'Bugi',
'sk',
'Sk',
'hebr',
'Hebr',
'lu',
'Lu',
'pe',
'Pe',
'tglg',
'Tglg',
'tagb',
'Tagb',
'mlym',
'Mlym',
'pf',
'Pf',
'no',
'No',
'grek',
'Grek',
'ethi',
'Ethi',
'mong',
'Mong',
'cc',
'Cc',
'hrkt',
'Hrkt',
'armn',
'Armn',
'zs',
'Zs',
'so',
'So',
'hani',
'Hani',
'shaw',
'Shaw',
'taml',
'Taml',
'me',
'Me',
'cf',
'Cf',
'nd',
'Nd',
's',
'S',
'guru',
'Guru',
'ugar',
'Ugar',
'qaai',
'Qaai',
'lt',
'Lt',
'c',
'C',
'pd',
'Pd',
'cyrl',
'Cyrl',
'l&',
'LC',
'thai',
'Thai',
'beng',
'Beng',
'brai',
'Brai',
'telu',
'Telu',
'pi',
'Pi',
'geor',
'Geor',
'glag',
'Glag',
'hang',
'Hang',
'syrc',
'Syrc',
'tfng',
'Tfng',
'n',
'N',
'dsrt',
'Dsrt',
'buhd',
'Buhd',
'm',
'M',
'khar',
'Khar',
'sm',
'Sm',
'nl',
'Nl',
'bopo',
'Bopo',
'linb',
'Linb',
'mn',
'Mn',
'l',
'L',
'p',
'P',
'goth',
'Goth',
'tale',
'Tale',
'lc',
'LC',
'zyyy',
'Zyyy',
'latn',
'Latn',
},
'NFC_QC',
{
'y',
'Y',
'n',
'N',
'm',
'M',
},
'NFD_QC',
{
'y',
'Y',
'n',
'N',
},
'hst',
{
'l',
'L',
'lvt',
'LVT',
'v',
'V',
'lv',
'LV',
't',
'T',
'na',
'NA',
},
'NFKC_QC',
{
'y',
'Y',
'n',
'N',
'm',
'M',
},
'WB',
{
'ml',
'ML',
'le',
'LE',
'ex',
'EX',
'xx',
'XX',
'nu',
'NU',
'fo',
'FO',
'mn',
'MN',
'ka',
'KA',
},
'SB',
{
'sp',
'SP',
'cl',
'CL',
'le',
'LE',
'up',
'UP',
'st',
'ST',
'xx',
'XX',
'nu',
'NU',
'fo',
'FO',
'se',
'SE',
'lo',
'LO',
'at',
'AT',
},
'bc',
{
'r',
'R',
'rlo',
'RLO',
'es',
'ES',
'ws',
'WS',
'rle',
'RLE',
'on',
'ON',
'bn',
'BN',
'et',
'ET',
'pdf',
'PDF',
'lro',
'LRO',
's',
'S',
'al',
'AL',
'en',
'EN',
'l',
'L',
'b',
'B',
'lre',
'LRE',
'cs',
'CS',
'nsm',
'NSM',
'an',
'AN',
},
'GCB',
{
'cn',
'CN',
'ex',
'EX',
'v',
'V',
'lv',
'LV',
'xx',
'XX',
'l',
'L',
'lvt',
'LVT',
'cr',
'CR',
'lf',
'LF',
't',
'T',
},
'ccc',
{
'atb',
'ATB',
'db',
'DB',
'a',
'A',
'r',
'R',
'da',
'DA',
'is',
'IS',
'nr',
'NR',
'ov',
'OV',
'br',
'BR',
'nk',
'NK',
'atbl',
'ATBL',
'al',
'AL',
'ar',
'AR',
'atar',
'ATAR',
'l',
'L',
'b',
'B',
'vr',
'VR',
'kv',
'KV',
'bl',
'BL',
},
'lb',
{
'sp',
'SP',
'ba',
'BA',
'gl',
'GL',
'xx',
'XX',
'nu',
'NU',
'cb',
'CB',
'sy',
'SY',
'cr',
'CR',
'in',
'IN',
'bb',
'BB',
'sg',
'SG',
'sa',
'SA',
'po',
'PO',
'jl',
'JL',
'id',
'ID',
'al',
'AL',
'bk',
'BK',
'pr',
'PR',
'b2',
'B2',
'op',
'OP',
'cl',
'CL',
'is',
'IS',
'qu',
'QU',
'hy',
'HY',
'wj',
'WJ',
'zw',
'ZW',
'jt',
'JT',
'ex',
'EX',
'cm',
'CM',
'h2',
'H2',
'nl',
'NL',
'ns',
'NS',
'h3',
'H3',
'ai',
'AI',
'lf',
'LF',
'jv',
'JV',
},
);
1;
