# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# This file supports:
# 	\p{Cypriot} (and fuzzy permutations)
# 
# Meaning: Script 'Cypriot'
#
return <<'END';
10800	10805	Cypriot
10808		Cypriot
1080A	10835	Cypriot
10837	10838	Cypriot
1083C		Cypriot
1083F		Cypriot
END
