# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# Linebreak category 'Postfix_Numeric'
#
return <<'END';
0025		
00A2		
00B0		
060B		
2030	2037	
20A7		
2103		
2109		
FDFC		
FE6A		
FF05		
FFE0		
END
