# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# This file supports:
# 	\p{Kharoshthi} (and fuzzy permutations)
# 
# Meaning: Script 'Kharoshthi'
#
return <<'END';
10A00	10A03	Kharoshthi
10A05	10A06	Kharoshthi
10A0C	10A13	Kharoshthi
10A15	10A17	Kharoshthi
10A19	10A33	Kharoshthi
10A38	10A3A	Kharoshthi
10A3F	10A47	Kharoshthi
10A50	10A58	Kharoshthi
END
