# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# This file supports:
# 	\p{Lao} (and fuzzy permutations)
# 
# Meaning: Script 'Lao'
#
return <<'END';
0E81	0E82	Lao
0E84		Lao
0E87	0E88	Lao
0E8A		Lao
0E8D		Lao
0E94	0E97	Lao
0E99	0E9F	Lao
0EA1	0EA3	Lao
0EA5		Lao
0EA7		Lao
0EAA	0EAB	Lao
0EAD	0EB9	Lao
0EBB	0EBD	Lao
0EC0	0EC4	Lao
0EC6		Lao
0EC8	0ECD	Lao
0ED0	0ED9	Lao
0EDC	0EDD	Lao
END
