# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

##
## Data in this file used by ../utf8_heavy.pl
##

## Mapping from name to filename in ./lib/gc_sc
%utf8::Exact = (
 ASCII		=> 'ASCII',
 All		=> 'Any',
 Alnum		=> 'Alnum',
 Alpha		=> 'Alpha',
 Any		=> 'Any',
 Assigned	=> 'Assigned',
 Blank		=> 'Blank',
 C		=> 'C',
 Cc		=> 'Cc',
 Cf		=> 'Cf',
 Cn		=> 'Cn',
 Cntrl		=> 'Cntrl',
 Co		=> 'Co',
 Cs		=> 'Cs',
 Digit		=> 'Digit',
 Graph		=> 'Graph',
 InGreek	=> 'InGreekA',
 L		=> 'L',
 LC		=> 'LC',
 Ll		=> 'Ll',
 Lm		=> 'Lm',
 Lo		=> 'Lo',
 Lower		=> 'Lower',
 Lt		=> 'Lt',
 Lu		=> 'Lu',
 M		=> 'M',
 Mc		=> 'Mc',
 Me		=> 'Me',
 Mn		=> 'Mn',
 N		=> 'N',
 Nd		=> 'Nd',
 Nl		=> 'Nl',
 No		=> 'No',
 P		=> 'P',
 Pc		=> 'Pc',
 Pd		=> 'Pd',
 Pe		=> 'Pe',
 Pf		=> 'Pf',
 Pi		=> 'Pi',
 Po		=> 'Po',
 Print		=> 'Print',
 Ps		=> 'Ps',
 Punct		=> 'Punct',
 S		=> 'S',
 Sc		=> 'Sc',
 Sk		=> 'Sk',
 Sm		=> 'Sm',
 So		=> 'So',
 Space		=> 'Space',
 SpacePerl	=> 'SpacePer',
 Title		=> 'Title',
 Upper		=> 'Upper',
 Word		=> 'Word',
 XDigit 	=> 'XDigit',
 Z		=> 'Z',
 Zl		=> 'Zl',
 Zp		=> 'Zp',
 Zs		=> 'Zs',
 _CanonDCIJ	=> '_CanonDC',
 _CaseIgnorable  => '_CaseIgn',
 _CombAbove	=> '_CombAbo',
);
1;
