# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# This file supports:
# 	\p{Nl}
# 	\p{Nl} (and fuzzy permutations)
# 
# Meaning: General Category 'Nl'
#
return <<'END';
16EE	16F0	
2160	2183	
3007		
3021	3029	
3038	303A	
10140	10174	
1034A		
103D1	103D5	
END
