# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# DecompositionType category 'Circle'
#
return <<'END';
2460	2473	
24B6	24EA	
3251	327E	
3280	32BF	
32D0	32FE	
END
