# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# Linebreak category 'Nonstarter'
#
return <<'END';
17D6	17D7	
17D9		
203C		
3005		
301C		
303B	303C	
3041		
3043		
3045		
3047		
3049		
3063		
3083		
3085		
3087		
308E		
3095	3096	
309B	309E	
30A0	30A1	
30A3		
30A5		
30A7		
30A9		
30C3		
30E3		
30E5		
30E7		
30EE		
30F5	30F6	
30FB	30FE	
31F0	31FF	
A015		
FE54	FE55	
FF1A	FF1B	
FF65		
FF67	FF70	
FF9E	FF9F	
END
