# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# This file supports:
# 	\p{Katakana} (and fuzzy permutations)
# 
# Meaning: Script 'Katakana'
#
return <<'END';
30A1	30FA	Katakana
30FD	30FF	Katakana
31F0	31FF	Katakana
FF66	FF6F	Katakana
FF71	FF9D	Katakana
END
