# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# DecompositionType category 'Isolated'
#
return <<'END';
FB50		
FB52		
FB56		
FB5A		
FB5E		
FB62		
FB66		
FB6A		
FB6E		
FB72		
FB76		
FB7A		
FB7E		
FB82		
FB84		
FB86		
FB88		
FB8A		
FB8C		
FB8E		
FB92		
FB96		
FB9A		
FB9E		
FBA0		
FBA4		
FBA6		
FBAA		
FBAE		
FBB0		
FBD3		
FBD7		
FBD9		
FBDB		
FBDD	FBDE	
FBE0		
FBE2		
FBE4		
FBEA		
FBEC		
FBEE		
FBF0		
FBF2		
FBF4		
FBF6		
FBF9		
FBFC		
FC00	FC63	
FCF5	FD10	
FD3D		
FDF0	FDFC	
FE70		
FE72		
FE74		
FE76		
FE78		
FE7A		
FE7C		
FE7E		
FE80	FE81	
FE83		
FE85		
FE87		
FE89		
FE8D		
FE8F		
FE93		
FE95		
FE99		
FE9D		
FEA1		
FEA5		
FEA9		
FEAB		
FEAD		
FEAF		
FEB1		
FEB5		
FEB9		
FEBD		
FEC1		
FEC5		
FEC9		
FECD		
FED1		
FED5		
FED9		
FEDD		
FEE1		
FEE5		
FEE9		
FEED		
FEEF		
FEF1		
FEF5		
FEF7		
FEF9		
FEFB		
END
