# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# This file supports:
# 	\p{XDigit}
# 
# Meaning: [[:XDigit:]]
#
return <<'END';
0030	0039	
0041	0046	
0061	0066	
END
