# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# Linebreak category 'Complex_Context'
#
return <<'END';
0E01	0E30	
0E32	0E33	
0E40	0E46	
0E81	0E82	
0E84		
0E87	0E88	
0E8A		
0E8D		
0E94	0E97	
0E99	0E9F	
0EA1	0EA3	
0EA5		
0EA7		
0EAA	0EAB	
0EAD	0EB0	
0EB2	0EB3	
0EBD		
0EC0	0EC4	
0EC6		
0EDC	0EDD	
1000	1021	
1023	1027	
1029	102A	
1050	1055	
1780	17B5	
END
