# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# DecompositionType category 'Super'
#
return <<'END';
00AA		
00B2	00B3	
00B9	00BA	
02B0	02B8	
02E0	02E4	
10FC		
1D2C	1D2E	
1D30	1D3A	
1D3C	1D4D	
1D4F	1D61	
1D78		
1D9B	1DBF	
2070	2071	
2074	207F	
2120		
2122		
2D6F		
3192	319F	
END
