# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# BidiClass category 'Segment_Separator'
#
return <<'END';
0009		
000B		
001F		
END
