# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# Linebreak category 'Prefix_Numeric'
#
return <<'END';
0024		
002B		
005C		
00A3	00A5	
00B1		
09F2	09F3	
0AF1		
0BF9		
0E3F		
17DB		
20A0	20A6	
20A8	20B5	
2116		
2212	2213	
FE69		
FF04		
FFE1		
FFE5	FFE6	
END
