# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# JoiningType category 'Dual_Joining'
#
return <<'END';
0626		
0628		
062A	062E	
0633	063A	
0641	0647	
0649	064A	
066E	066F	
0678	0687	
069A	06BF	
06C1	06C2	
06CC		
06CE		
06D0	06D1	
06FA	06FC	
06FF		
0712	0714	
071A	071D	
071F	0727	
0729		
072B		
072D	072E	
074E	0758	
075C	076A	
076D		
END
