# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# EastAsianWidth category 'Wide'
#
return <<'END';
1100	1159	
115F		
2329	232A	
2E80	2E99	
2E9B	2EF3	
2F00	2FD5	
2FF0	2FFB	
3001	303E	
3041	3096	
3099	30FF	
3105	312C	
3131	318E	
3190	31B7	
31C0	31CF	
31F0	321E	
3220	3243	
3250	32FE	
3300	4DB5	
4E00	9FBB	
A000	A48C	
A490	A4C6	
AC00	D7A3	
F900	FA2D	
FA30	FA6A	
FA70	FAD9	
FE10	FE19	
FE30	FE52	
FE54	FE66	
FE68	FE6B	
20000	2FFFD	
30000	3FFFD	
END
