# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# This file supports:
# 	\p{Han} (and fuzzy permutations)
# 
# Meaning: Script 'Han'
#
return <<'END';
2E80	2E99	Han
2E9B	2EF3	Han
2F00	2FD5	Han
3005		Han
3007		Han
3021	3029	Han
3038	303B	Han
3400	4DB5	Han
4E00	9FBB	Han
F900	FA2D	Han
FA30	FA6A	Han
FA70	FAD9	Han
20000	2A6D6	Han
2F800	2FA1D	Han
END
