# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# This file supports:
# 	\p{Khmer} (and fuzzy permutations)
# 
# Meaning: Script 'Khmer'
#
return <<'END';
1780	17DD	Khmer
17E0	17E9	Khmer
17F0	17F9	Khmer
19E0	19FF	Khmer
END
