# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# This file supports:
# 	\p{Z}
# 	\p{Z} (and fuzzy permutations)
# 
# Meaning: Major Category 'Z'
#
return <<'END';
0020		
00A0		
1680		
180E		
2000	200A	
2028	2029	
202F		
205F		
3000		
END
