# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# This file supports:
# 	\p{Oriya} (and fuzzy permutations)
# 
# Meaning: Script 'Oriya'
#
return <<'END';
0B01	0B03	Oriya
0B05	0B0C	Oriya
0B0F	0B10	Oriya
0B13	0B28	Oriya
0B2A	0B30	Oriya
0B32	0B33	Oriya
0B35	0B39	Oriya
0B3C	0B43	Oriya
0B47	0B48	Oriya
0B4B	0B4D	Oriya
0B56	0B57	Oriya
0B5C	0B5D	Oriya
0B5F	0B61	Oriya
0B66	0B71	Oriya
END
