# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# This file supports:
# 	\p{Cyrillic} (and fuzzy permutations)
# 
# Meaning: Script 'Cyrillic'
#
return <<'END';
0400	0486	Cyrillic
0488	04CE	Cyrillic
04D0	04F9	Cyrillic
0500	050F	Cyrillic
1D2B		Cyrillic
1D78		Cyrillic
END
