# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# This file supports:
# 	\p{Telugu} (and fuzzy permutations)
# 
# Meaning: Script 'Telugu'
#
return <<'END';
0C01	0C03	Telugu
0C05	0C0C	Telugu
0C0E	0C10	Telugu
0C12	0C28	Telugu
0C2A	0C33	Telugu
0C35	0C39	Telugu
0C3E	0C44	Telugu
0C46	0C48	Telugu
0C4A	0C4D	Telugu
0C55	0C56	Telugu
0C60	0C61	Telugu
0C66	0C6F	Telugu
END
