# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# BidiClass category 'European_Separator'
#
return <<'END';
002B		
002D		
207A	207B	
208A	208B	
2212		
FB29		
FE62	FE63	
FF0B		
FF0D		
END
