# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# BidiClass category 'Common_Separator'
#
return <<'END';
002C		
002E	002F	
003A		
00A0		
060C		
202F		
2044		
FE50		
FE52		
FE55		
FF0C		
FF0E	FF0F	
FF1A		
END
