# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# This file supports:
# 	\p{Pf}
# 	\p{Pf} (and fuzzy permutations)
# 
# Meaning: General Category 'Pf'
#
return <<'END';
00BB		
2019		
201D		
203A		
2E03		
2E05		
2E0A		
2E0D		
2E1D		
END
