# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# This file supports:
# 	\p{Title}
# 
# Meaning: [[:Title:]]
#
return <<'END';
01C5		
01C8		
01CB		
01F2		
1F88	1F8F	
1F98	1F9F	
1FA8	1FAF	
1FBC		
1FCC		
1FFC		
END
