# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# This file supports:
# 	\p{OtherMath} (and fuzzy permutations)
# 
# Meaning: Extended property 'Other_Math'
#
return <<'END';
005E		Other_Math
03D0	03D2	Other_Math
03D5		Other_Math
03F0	03F1	Other_Math
03F4	03F5	Other_Math
2016		Other_Math
2032	2034	Other_Math
2040		Other_Math
2061	2063	Other_Math
207D	207E	Other_Math
208D	208E	Other_Math
20D0	20DC	Other_Math
20E1		Other_Math
20E5	20E6	Other_Math
2102		Other_Math
210A	2113	Other_Math
2115		Other_Math
2119	211D	Other_Math
2124		Other_Math
2128	2129	Other_Math
212C	212D	Other_Math
212F	2131	Other_Math
2133	2138	Other_Math
213C	213F	Other_Math
2145	2149	Other_Math
23B7		Other_Math
23D0		Other_Math
27C5	27C6	Other_Math
27E6	27EB	Other_Math
2983	2998	Other_Math
29D8	29DB	Other_Math
29FC	29FD	Other_Math
FE61		Other_Math
FE63		Other_Math
FE68		Other_Math
FF3C		Other_Math
FF3E		Other_Math
1D400	1D454	Other_Math
1D456	1D49C	Other_Math
1D49E	1D49F	Other_Math
1D4A2		Other_Math
1D4A5	1D4A6	Other_Math
1D4A9	1D4AC	Other_Math
1D4AE	1D4B9	Other_Math
1D4BB		Other_Math
1D4BD	1D4C3	Other_Math
1D4C5	1D505	Other_Math
1D507	1D50A	Other_Math
1D50D	1D514	Other_Math
1D516	1D51C	Other_Math
1D51E	1D539	Other_Math
1D53B	1D53E	Other_Math
1D540	1D544	Other_Math
1D546		Other_Math
1D54A	1D550	Other_Math
1D552	1D6A3	Other_Math
1D6A8	1D6C0	Other_Math
1D6C2	1D6DA	Other_Math
1D6DC	1D6FA	Other_Math
1D6FC	1D714	Other_Math
1D716	1D734	Other_Math
1D736	1D74E	Other_Math
1D750	1D76E	Other_Math
1D770	1D788	Other_Math
1D78A	1D7A8	Other_Math
1D7AA	1D7C2	Other_Math
1D7C4	1D7C9	Other_Math
1D7CE	1D7FF	Other_Math
END
