# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# DecompositionType category 'Narrow'
#
return <<'END';
FF61	FFBE	
FFC2	FFC7	
FFCA	FFCF	
FFD2	FFD7	
FFDA	FFDC	
FFE8	FFEE	
END
