# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# This file supports:
# 	\p{Sk}
# 	\p{Sk} (and fuzzy permutations)
# 
# Meaning: General Category 'Sk'
#
return <<'END';
005E		
0060		
00A8		
00AF		
00B4		
00B8		
02C2	02C5	
02D2	02DF	
02E5	02ED	
02EF	02FF	
0374	0375	
0384	0385	
1FBD		
1FBF	1FC1	
1FCD	1FCF	
1FDD	1FDF	
1FED	1FEF	
1FFD	1FFE	
309B	309C	
A700	A716	
FF3E		
FF40		
FFE3		
END
