# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# Linebreak category 'Glue'
#
return <<'END';
00A0		
034F		
035D	0362	
0F08		
0F0C		
0F12		
180E		
2007		
2011		
202F		
END
