# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# Linebreak category 'Exclamation'
#
return <<'END';
0021		
003F		
05C6		
060C		
061B		
061E	061F	
066A		
06D4		
0F0D	0F11	
0F14		
1944	1945	
2762	2763	
FE15	FE16	
FE56	FE57	
FF01		
FF1F		
END
