# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# BidiClass category 'Right_To_Left'
#
return <<'END';
05BE		
05C0		
05C3		
05C6		
05D0	05EA	
05F0	05F4	
200F		
FB1D		
FB1F	FB28	
FB2A	FB36	
FB38	FB3C	
FB3E		
FB40	FB41	
FB43	FB44	
FB46	FB4F	
10800	10805	
10808		
1080A	10835	
10837	10838	
1083C		
1083F		
10A00		
10A10	10A13	
10A15	10A17	
10A19	10A33	
10A40	10A47	
10A50	10A58	
END
