# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# This file supports:
# 	\p{Me}
# 	\p{Me} (and fuzzy permutations)
# 
# Meaning: General Category 'Me'
#
return <<'END';
0488	0489	
06DE		
20DD	20E0	
20E2	20E4	
END
