# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# This file supports:
# 	\p{Devanagari} (and fuzzy permutations)
# 
# Meaning: Script 'Devanagari'
#
return <<'END';
0901	0939	Devanagari
093C	094D	Devanagari
0950	0954	Devanagari
0958	0963	Devanagari
0966	096F	Devanagari
097D		Devanagari
END
