# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# This file supports:
# 	\p{PatternWhiteSpace} (and fuzzy permutations)
# 
# Meaning: Extended property 'Pattern_White_Space'
#
return <<'END';
0009	000D	Pattern_White_Space
0020		Pattern_White_Space
0085		Pattern_White_Space
200E	200F	Pattern_White_Space
2028	2029	Pattern_White_Space
END
