# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# Binary property 'Other_Default_Ignorable_Code_Point'
#
return <<'END';
034F		Other_Default_Ignorable_Code_Point
115F	1160	Other_Default_Ignorable_Code_Point
2064	2069	Other_Default_Ignorable_Code_Point
3164		Other_Default_Ignorable_Code_Point
FFA0		Other_Default_Ignorable_Code_Point
FFF0	FFF8	Other_Default_Ignorable_Code_Point
E0000		Other_Default_Ignorable_Code_Point
E0002	E001F	Other_Default_Ignorable_Code_Point
E0080	E00FF	Other_Default_Ignorable_Code_Point
E01F0	E0FFF	Other_Default_Ignorable_Code_Point
END
