# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# This file supports:
# 	\p{Buginese} (and fuzzy permutations)
# 
# Meaning: Script 'Buginese'
#
return <<'END';
1A00	1A1B	Buginese
1A1E	1A1F	Buginese
END
