# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# Linebreak category 'JL'
#
return <<'END';
1100	1159	
115F		
END
